@@ -4,7 +4,7 @@ use strict;
 use warnings;
 package Alien::Sodium;
 our $AUTHORITY = 'cpan:AJGB';
-$Alien::Sodium::VERSION = '1.0.6.0';
+$Alien::Sodium::VERSION = '1.0.6.1';
 use parent 'Alien::Base';
 
 1;
@@ -21,7 +21,7 @@ Alien::Sodium - Install and make available libsodium library
 
 =head1 VERSION
 
-version 1.0.6.0
+version 1.0.6.1
 
 =head1 SYNOPSIS
 
@@ -32,8 +32,8 @@ version 1.0.6.0
 
 =head1 DESCRIPTION
 
-Alien::Sodium installs the C library C<libsodium> version 1.0.6 released on
-November 1, 2015.
+Alien::Sodium installs the C library C<libsodium> version 1.0.7 released on
+December 9, 2015.
 
 =head1 SEE ALSO
 
